{% extends "_raw.html" %}

{% load i18n %}
{% load static %}

{% block raw_content %}
<div class="min-h-screen min-w-screen flex flex-col justify-center bg-gray-100 px-3 py-10">
    <div class="mx-auto w-136">
        <a href="/">
            <div class="h-36 mb-3 bg-{{ BRANDING }}-logo hover:bg-{{ BRANDING }}-logo-hover bg-contain bg-center bg-no-repeat"></div>
        </a>
        <div class="bg-white shadow-md rounded p-6 mb-4">
            <h1 class="heading text-center mb-4">{% block heading %}{% endblock %}</h1>
            {% include "messages.html" %}
            {% block content %}{% endblock content %}
        </div>
        <p class="text-center text-gray-400">
	        &copy;2016 - {% now "Y" %}
            <a href="{{ COMPANY_URL }}"
               class="text-gray-600 hover:text-gray-800"
               target="_blank"
               rel="noopener noreferrer">
                {{ COMPANY }}
            </a>
        </p>
    </div>
</div>
{% endblock %}
