{% with page=request.GET.page size=request.GET.size %}

{% if page %} <input type="hidden" name="page" value="{{ page }}" />{% endif %}
{% if size %} <input type="hidden" name="size" value="{{ size }}" />{% endif %}

{% endwith %}