{% extends "authentication/_base.html" %}

{% load i18n %}

{% block heading %}
    {{ title }}
{% endblock %}

{% block content %}
    <h2 class="text-2xl mb-4 text-center">{% trans 'Error' %} {{ code }}</h2>
    <p class="mb-4 text-lg">
        {{ message }}
    </p>
    <a href="/" class="btn w-full text-center">
        <i data-feather="arrow-left-circle" class="align-top"></i> {% trans 'Return back home' %}
    </a>
{% endblock %}
