"""
This package contains views for the broken link checker
"""
from .linkcheck_list_view import LinkcheckListView
from .linkcheck_redirect_view import LinkcheckRedirectView
from .linkcheck_stats_view import LinkcheckStatsView
