"""
Meta information about the Integreat CMS API app
"""
from django.apps import AppConfig


class ApiConfig(AppConfig):
    """
    Configuration parameters for the API app
    """

    name = "integreat_cms.api"
