{% load i18n %}

<tr class="border-t border-solid border-gray-200 hover:bg-gray-100">
    <td class="pl-2">
        <a href="{% url 'edit_organization' region_slug=request.region.slug slug=organization.slug %}" class="block py-3 px-2 text-gray-800">
            {{ organization.name }}
        </a>
    </td>
	<td>
        <a href="{% url 'edit_organization' region_slug=request.region.slug slug=organization.slug %}" class="block py-3 px-2 text-gray-800">
            {{ organization.slug }}
        </a>
	</td>
	<td class="pr-2">
        {% if organization.icon %}
            <a href="{% url 'edit_organization' region_slug=request.region.slug slug=organization.slug %}">
                <img src="{{ organization.icon.url }}" alt="{{ organization.icon.url }}" style="max-height:48px">
            </a>
        {% else %}
            <i data-feather="x" class="text-red-500"></i>
        {% endif %}
	</td>
    <td class="pl-2 pr-4 text-right min">
        {% if perms.cms.delete_organization %}
            <button title="{% trans 'Delete organization' %}" class="confirmation-button btn-icon"
                    data-confirmation-title="{{ delete_dialog_title }}"
                    data-confirmation-text="{{ delete_dialog_text }}"
                    data-confirmation-subject="{{ organization.name }}"
                    data-action="{% url 'delete_organization' region_slug=request.region.slug slug=organization.slug %}">
                <i data-feather="trash-2"></i>
            </button>
        {% endif %}
    </td>
</tr>
