"""
This module contains custom strings which are not picked up by the normal makemessages command
"""
from django.utils.translation import ugettext_lazy as _


_("Easy German")
_("German (easy)")
_("Amharic")
