"""
Configuration of XLIFF app
"""
from django.apps import AppConfig


class XLIFFConfig(AppConfig):
    """
    XLIFF config inheriting the django AppConfig
    """

    name = "integreat_cms.xliff"
