"""
This package contains all views related to push notifications
"""
from .push_notification_list_view import PushNotificationListView
from .push_notification_form_view import PushNotificationFormView
