{% extends "_base.html" %}

{% load i18n %}
{% load static %}
{% load widget_tweaks %}

{% block content %}
    <div class="dashboard">
        <h1 class="heading">{% trans 'My Dashboard' %}</h1>
        <div class="xl:flex gap-3 pt-2">
            <div class="xl:w-1/2">
                <!-- Statistic Widget -->
                {% if request.region.statistics_enabled %}
                    {% include "statistics/_statistics_widget.html" %}
                {% endif %}
                <!-- Chat Widget -->
                {% if chat_form and perms.cms.change_chatmessage %}
                    {% include "chat/_chat_widget.html" %}
                {% endif %}
                <!-- Translation Status Widget: TODO-->
                <!-- App Size Widget: TODO -->
            </div>
            <div class="xl:w-1/2">
                <!-- Broken Link Widget -->
                {% include "analytics/_broken_links_widget.html" %}
                <!-- News Widget -->
                {% include "dashboard/_news_widget.html" %}
            </div>
        </div>
    </div>
{% include "../generic_confirmation_dialog.html" %}
{% endblock %}
