{% extends "_collapsible_box.html" %}

{% load i18n %}
{% load static %}

{% block collapsible_box_icon %}
    check-circle
{% endblock %}

{% block collapsible_box_title %}
    {% trans 'Translation Status' %}
{% endblock %}

{% block collapsible_box_content %}
    <div class="flex flex-wrap justify-between gap-2">
        <p class="py-3"> {% trans 'The list below shows the current status of the translations.' %}</p>
        <a href="{% url 'translation_coverage' region_slug=request.region.slug %}" class="btn">
            {% trans "Details" %}
        </a>
    </div>
    <div class="p-3 w-full">
        <!-- TODO -->
    </div>
{% endblock %}
