{% load i18n %}
{% load content_filters %}

{% get_current_language as LANGUAGE_CODE %}
{% get_language LANGUAGE_CODE as backend_language %}
<table>
    <tbody>
        {% for page in pages %}
            {% include "pages/page_tree_node.html" %}
        {% endfor %}
    </tbody>
</table>
