{% load text_filters %}
{% load i18n %}

<div
    id="content-edit-lock-data"
    data-heartbeat-url="{% url 'content_edit_lock_heartbeat' region_slug=request.region.slug %}"
    data-lock-release-url="{% url 'content_edit_lock_release' region_slug=request.region.slug %}"
    data-heartbeat-payload="{{ lock_key|to_json }}"
    data-cancel-url="{{ back_url }}"
    data-popup-title-locked="{% trans '{} is already editing this content' %}"
    data-popup-title-takeover="{% trans 'This content got locked by {}' %}"
    data-popup-subject="{% trans 'Do you want to take over this site?' %}"
    data-popup-text="{% trans 'Continuing will prevent the current editor from working on it.' %}"
></div>
