{% extends "emails/_base_email.html" %}

{% load i18n %}

{% block content %}
	{% trans 'Welcome' %} {{ user.full_user_name }},
    <br>
    <br>
	{% blocktrans trimmed %}
		You are receiving this e-mail, because you have requested a password reset for your {{ BRANDING }} account.
	{% endblocktrans %}
    <br>
	{% trans 'Please use the following link to set a new password:' %}
    <br>
    <br>
	<a href="{{ protocol }}://{{ domain }}{% url 'public:password_reset_confirm' uidb64=uid token=token %}">
		{{ protocol }}://{{ domain }}{% url 'public:password_reset_confirm' uidb64=uid token=token %}
	</a>
    <br>
    <br>
	{% trans 'If clicking on the link above does not work, please copy the URL and paste it into the address bar of your browser.' %}
    <br>
    <br>
	{% trans "Your username, in case you've forgotten:" %} <b>{{ user.get_username }}</b>
{% endblock content %}
