"""
This package contains all views related to statistics
"""
from .statistics_view import AnalyticsView
from .statistics_actions import (
    get_total_visits_ajax,
    get_visits_per_language_ajax,
)
