{% extends "_collapsible_box.html" %}

{% load i18n %}
{% load static %}
{% load parse_struct_time %}

{% block collapsible_box_icon %}
    trello
{% endblock %}

{% block collapsible_box_title %}
    {% trans 'Integreat News' %}
{% endblock %}

{% block collapsible_box_content %}
    <div class="rss-feed " data-feed-url="{{ feed_url }}">
        <div id="feed-loading" class="px-4 hidden"><i data-feather="loader" class="animate-spin"></i> {% trans 'Loading...' %}</div>
    </div>
    <div id="reload" class="hidden"> 
        <div class="text-red-500 px-4"><i data-feather="alert-triangle"></i> {% trans "Unfortunately there was a problem and the news feed could not load." %} </div>
        <button id="reload-button" class="btn">
            <i data-feather="refresh-ccw"></i> {% trans "Reload page" %}
        </button>
    </div>
    <button id="read-more" class="btn hidden">
        <i data-feather="book-open"></i> {% trans "Continue reading" %}
    </button>
{% endblock %}
