# Generated by Django 3.2.13 on 2022-05-24 21:31

from django.db import migrations, models


class Migration(migrations.Migration):
    """
    Update the help text for the expert mode
    """

    dependencies = [
        ("cms", "0027_alter_recurrencerule_week_for_monthly"),
    ]

    operations = [
        migrations.AlterField(
            model_name="user",
            name="expert_mode",
            field=models.BooleanField(
                default=False,
                help_text="Enable this option to display additional features like XLIFF import/export, page filtering, mirrored pages, page-based permissions, do-not-translate-tag and status information for broken links",
                verbose_name="experienced user",
            ),
        ),
    ]
